import { ElMessage } from 'element-plus'
import {useStore} from '@/store/modules/app';
import api from '@/api/methods/index';
import axios from "axios"
export default {
	setStorage(key,value,expire=15552000){
		localStorage.setItem(key,JSON.stringify({
			value:value,
			now:Date.now(),
			expire:expire
		}))
	},
	getStorage(key){
		if (localStorage.getItem(key)){
			let obj = this.isJsonString(localStorage.getItem(key))?JSON.parse(localStorage.getItem(key)):{value:null,now:0,
				expire:0};
			if(Date.now()>obj.now+obj.expire*1000){
				return null;
			}else{
				return obj.value;
			}
		} else{
			return null;
		}
	},
	//判断是否是json字符串
	isJsonString(str) {
		try {
			if (str === null) {
				return false;
			}
			if (typeof JSON.parse(str) == "object") {
				return true;
			}
		} catch (e) {}
		return false;
	},
	//判断一个数据是否为空
	isEmpty(str) {
		if (Object.prototype.toString.call(str) === '[object Undefined]') { //空
			return true
		} else if (
			Object.prototype.toString.call(str) === '[object String]' ||
			Object.prototype.toString.call(str) === '[object Array]') { //字条串或数组
			return str.length == 0 ? true : false
		} else if (Object.prototype.toString.call(str) === '[object Object]') {
			return JSON.stringify(str) == '{}' ? true : false
		} else if (Object.prototype.toString.call(str) === '[object Number]') {
			return str == NaN ? true : false
		} else {
			return true
		}
	},
	//获取url参数
	getUrlKey(name) {

		return (
			decodeURIComponent(
				(new RegExp("[?|&]" + name + "=" + "([^&;]+?)(&|#|;|$)").exec(
					location.href
				) || [, ""])[1].replace(/\+/g, "%20")
			) || null
		);
	},
	//时间封装
	dateFormat: {
		//日期格式化
		/**
		 * @param date 标准时间日期格式
		 * @param fmt 格式化格式
		 * @returns {string}
		 */
		format(date, fmt = 'YYYY-MM-DD HH:mm:ss') {
			date = new Date(date).getTime();
			date = new Date(date);
			let o = {
				'M+': date.getMonth() + 1,
				'D+': date.getDate(),
				'h+': date.getHours() % 12 === 0 ? 12 : date.getHours() % 12,
				'H+': date.getHours(),
				'm+': date.getMinutes(),
				's+': date.getSeconds(),
				'q+': Math.floor((date.getMonth() + 3) / 3),
				'S': date.getMilliseconds()
			};
			let week = {
				'0': '\u65e5',
				'1': '\u4e00',
				'2': '\u4e8c',
				'3': '\u4e09',
				'4': '\u56db',
				'5': '\u4e94',
				'6': '\u516d'
			};
			if (/(Y+)/.test(fmt)) {
				fmt = fmt.replace(RegExp.$1, (date.getFullYear() + '').substr(4 - RegExp.$1.length))
			}
			if (/(E+)/.test(fmt)) {
				fmt = fmt.replace(RegExp.$1, ((RegExp.$1.length > 1) ? (RegExp.$1.length > 2 ? '\u661f\u671f' : '\u5468') : '') + week[date.getDay() + ''])
			}
			for (let k in o) {
				if (new RegExp('(' + k + ')').test(fmt)) {
					fmt = fmt.replace(RegExp.$1, (RegExp.$1.length === 1) ? (o[k]) : (('00' + o[k]).substr(('' + o[k]).length)))
				}
			}
			return fmt
		},
		//格式日期兼容苹果端日期获取
		dateReplace(date) {
			return date.replace(/\-/g, '/');
		}
	},
	upload_file(fileList,callBack){
		let uploadList=[];
		for(let file of fileList){
			this.dealFile(file,function (data) {
				uploadList.push(data);
				if(uploadList.length==fileList.length){
					callBack(uploadList);
				}
			})
		}
	},
	async dealFile(file,callBack){
		const store = useStore();
		if(file.type.indexOf('image')>=0){
			let expire = sessionStorage.getItem('oss-expire');
			if(Number(expire) < Date.now()/1000 + 3||!store.ossInfo.expire){
				await this.getOssConfig();
			}
			let formData = new FormData();
			let fileName = '',FILEURL='';
			if (file.name != '') {
				fileName = this.set_file_name(file.name);
			}
			FILEURL = store.ossInfo.dir + '/' + encodeURIComponent(fileName);
			formData.append("key", FILEURL);
			formData.append("policy", store.ossInfo.policy);
			formData.append("OSSAccessKeyId", store.ossInfo.accessid);
			formData.append("success_action_status", '200');
			formData.append("signature", store.ossInfo.signature);
			formData.append("file", file);
			axios({
				method: "post",
				url: store.ossInfo.host,
				data: formData,
				headers: {
					"Content-Type": "multipart/form-data"
				},
				//原生获取上传进度的事件
				onUploadProgress:(progressEvent)=>{
					let complete = (progressEvent.loaded / progressEvent.total * 100 | 0) + '%';
					// console.log('上传 ' + complete);
					ElMessage.closeAll();
					ElMessage({
						message:`上传中...${complete}`,
						type:'info'
					})
				}
			}).then((res)=>{
				console.log('res',res);
				if (res.status == 200){
					let type=''
					if(file.type.indexOf('image')!=-1){
						type=1
					}else if(file.type.indexOf('application')!=-1||file.type.indexOf('text')!=-1){
						type=3
					}else{
						type=100
					}
					let params={
						name:fileName,
						url:"https:"+store.ossInfo.host+"/"+FILEURL,
						type:type,
						size:file.size,
						ext:fileName.substring(fileName.lastIndexOf('.')),
						object_name:FILEURL
					};
					callBack(params);
				}
			});
		}else{
			if(file.type.indexOf('image')==-1){
				ElMessage({
					message:`请上传正确的图片格式`,
					type:'error'
				});
			}
		}
	},
	set_file_name(filename) {
		let pos = filename.lastIndexOf('.');
		let suffix = '',
			file = '';
		if (pos != -1) {
			suffix = filename.substring(pos);
			file = filename.substring(0, pos).replace(/#/g, '0')
		}
		let random = Date.now() + "_" + this.random_string(10)+"_";
		return random + suffix;
	},
	// 设置随机数
	random_string(len) {
		let lens = len || 32;
		let chars = 'ABCDEFGHJKMNPQRSTWXYZabcdefhijkmnprstwxyz2345678';
		let maxPos = chars.length;
		let pwd = '';
		for (let i = 0; i < lens; i++) {
			pwd += chars.charAt(Math.floor(Math.random() * maxPos));
		}
		return pwd;
	},
	getOssConfig() {
		const store = useStore();
		return api.getOssConfig().then((res)=>{
			if(res.code==0){
				store.oss_info(res.data);
				sessionStorage.setItem('oss-expire',res.data.expire);
			}
		})
	}
}
