const path = require("path");
const debug = process.env.NODE_ENV !== "production";
const webpack = require('webpack');
module.exports = {
	// 部署应用时的根路径(默认'/'),也可用相对路径(存在使用限制)
	publicPath:'/pc/',

	// 构建输出目录
	outputDir: "dist",

	// 静态资源目录 (js, css, img, fonts)
	assetsDir: "static",

	// 运行时版本是否需要编译
	runtimeCompiler: true,

	// 默认babel-loader忽略mode_modules，这里可增加例外的依赖包名
	transpileDependencies: [],

	// 是否在构建生产包时生成 sourceMap 文件，false将提高构建速度
	productionSourceMap: true,

	configureWebpack: config => { // webpack配置，值位对象时会合并配置，为方法时会改写配置
		if (debug) { // 开发环境配置
			config.devtool = "cheap-module-eval-source-map";
		} else { // 生产环境配置

		}
		Object.assign(config, { // 开发生产共同配置，配置别名
			resolve: {
				extensions: [".js", ".vue", ".json"],
				alias: {
					"@": path.resolve(__dirname, "./src")
				}
			},
			externals: {

			}
		});
	},
	// 构建时开启多进程处理babel编译
	parallel: require("os").cpus().length > 1,

	pages: {
		index: {
			// page 的入口
			entry: 'src/main.js',
			// 模板来源
			template: 'public/index.html',
			// 在 dist/index.html 的输出
			filename: 'index.html',
			// 当使用 title 选项时，
			// template 中的 title 标签需要是 <title><%= htmlWebpackPlugin.options.title %></title>
			title: '青山湖公厕',
			// 在这个页面中包含的块，默认情况下会包含
			// 提取出来的通用 chunk 和 vendor chunk。
			chunks: ['chunk-vendors', 'chunk-common', 'index']
		}
	},
	devServer:{
		open:true,
		port:80,
		proxy: {
			'/api': {
				target: 'http://127.0.0.1:8888',
				changeOrigin: true,
				pathRewrite: {
					//   '^/apis': ''表示把/apis替换为‘’(空字符串)，这样既能使用代理，
					//   又能在请求接口api时去掉/apis，获得正确的短信api路径。
					'^/api': ''
				},
			}
		}
	}
};
