package admin

import (
	"github.com/flipped-aurora/gin-vue-admin/server/global"
	"github.com/flipped-aurora/gin-vue-admin/server/model/admin"
	adminReq "github.com/flipped-aurora/gin-vue-admin/server/model/admin/request"
	"github.com/flipped-aurora/gin-vue-admin/server/model/common/request"
	"github.com/flipped-aurora/gin-vue-admin/server/model/common/response"
	"github.com/flipped-aurora/gin-vue-admin/server/service"
	"github.com/gin-gonic/gin"
	"go.uber.org/zap"
)

type QshMonitorDataApi struct {
}

var qshMonitorDataService = service.ServiceGroupApp.AdminServiceGroup.QshMonitorDataService

// CreateQshMonitorData 创建QshMonitorData
// @Tags QshMonitorData
// @Summary 创建QshMonitorData
// @Security ApiKeyAuth
// @accept application/json
// @Produce application/json
// @Param data body admin.QshMonitorData true "创建QshMonitorData"
// @Success 200 {string} string "{"success":true,"data":{},"msg":"获取成功"}"
// @Router /qshMonitorData/createQshMonitorData [post]
func (qshMonitorDataApi *QshMonitorDataApi) CreateQshMonitorData(c *gin.Context) {
	var qshMonitorData admin.QshMonitorData
	_ = c.ShouldBindJSON(&qshMonitorData)
	if err := qshMonitorDataService.CreateQshMonitorData(qshMonitorData); err != nil {
		global.GVA_LOG.Error("创建失败!", zap.Error(err))
		response.FailWithMessage("创建失败", c)
	} else {
		response.OkWithMessage("创建成功", c)
	}
}

// DeleteQshMonitorData 删除QshMonitorData
// @Tags QshMonitorData
// @Summary 删除QshMonitorData
// @Security ApiKeyAuth
// @accept application/json
// @Produce application/json
// @Param data body admin.QshMonitorData true "删除QshMonitorData"
// @Success 200 {string} string "{"success":true,"data":{},"msg":"删除成功"}"
// @Router /qshMonitorData/deleteQshMonitorData [delete]
func (qshMonitorDataApi *QshMonitorDataApi) DeleteQshMonitorData(c *gin.Context) {
	var qshMonitorData admin.QshMonitorData
	_ = c.ShouldBindJSON(&qshMonitorData)
	if err := qshMonitorDataService.DeleteQshMonitorData(qshMonitorData); err != nil {
		global.GVA_LOG.Error("删除失败!", zap.Error(err))
		response.FailWithMessage("删除失败", c)
	} else {
		response.OkWithMessage("删除成功", c)
	}
}

// DeleteQshMonitorDataByIds 批量删除QshMonitorData
// @Tags QshMonitorData
// @Summary 批量删除QshMonitorData
// @Security ApiKeyAuth
// @accept application/json
// @Produce application/json
// @Param data body request.IdsReq true "批量删除QshMonitorData"
// @Success 200 {string} string "{"success":true,"data":{},"msg":"批量删除成功"}"
// @Router /qshMonitorData/deleteQshMonitorDataByIds [delete]
func (qshMonitorDataApi *QshMonitorDataApi) DeleteQshMonitorDataByIds(c *gin.Context) {
	var IDS request.IdsReq
	_ = c.ShouldBindJSON(&IDS)
	if err := qshMonitorDataService.DeleteQshMonitorDataByIds(IDS); err != nil {
		global.GVA_LOG.Error("批量删除失败!", zap.Error(err))
		response.FailWithMessage("批量删除失败", c)
	} else {
		response.OkWithMessage("批量删除成功", c)
	}
}

// UpdateQshMonitorData 更新QshMonitorData
// @Tags QshMonitorData
// @Summary 更新QshMonitorData
// @Security ApiKeyAuth
// @accept application/json
// @Produce application/json
// @Param data body admin.QshMonitorData true "更新QshMonitorData"
// @Success 200 {string} string "{"success":true,"data":{},"msg":"更新成功"}"
// @Router /qshMonitorData/updateQshMonitorData [put]
func (qshMonitorDataApi *QshMonitorDataApi) UpdateQshMonitorData(c *gin.Context) {
	var qshMonitorData admin.QshMonitorData
	_ = c.ShouldBindJSON(&qshMonitorData)
	if err := qshMonitorDataService.UpdateQshMonitorData(qshMonitorData); err != nil {
		global.GVA_LOG.Error("更新失败!", zap.Error(err))
		response.FailWithMessage("更新失败", c)
	} else {
		response.OkWithMessage("更新成功", c)
	}
}

// FindQshMonitorData 用id查询QshMonitorData
// @Tags QshMonitorData
// @Summary 用id查询QshMonitorData
// @Security ApiKeyAuth
// @accept application/json
// @Produce application/json
// @Param data query admin.QshMonitorData true "用id查询QshMonitorData"
// @Success 200 {string} string "{"success":true,"data":{},"msg":"查询成功"}"
// @Router /qshMonitorData/findQshMonitorData [get]
func (qshMonitorDataApi *QshMonitorDataApi) FindQshMonitorData(c *gin.Context) {
	var qshMonitorData admin.QshMonitorData
	_ = c.ShouldBindQuery(&qshMonitorData)
	if reqshMonitorData, err := qshMonitorDataService.GetQshMonitorData(qshMonitorData.ID); err != nil {
		global.GVA_LOG.Error("查询失败!", zap.Error(err))
		response.FailWithMessage("查询失败", c)
	} else {
		response.OkWithData(gin.H{"reqshMonitorData": reqshMonitorData}, c)
	}
}

// GetQshMonitorDataList 分页获取QshMonitorData列表
// @Tags QshMonitorData
// @Summary 分页获取QshMonitorData列表
// @Security ApiKeyAuth
// @accept application/json
// @Produce application/json
// @Param data query adminReq.QshMonitorDataSearch true "分页获取QshMonitorData列表"
// @Success 200 {string} string "{"success":true,"data":{},"msg":"获取成功"}"
// @Router /qshMonitorData/getQshMonitorDataList [get]
func (qshMonitorDataApi *QshMonitorDataApi) GetQshMonitorDataList(c *gin.Context) {
	var pageInfo adminReq.QshMonitorDataSearch
	_ = c.ShouldBindQuery(&pageInfo)
	if list, total, err := qshMonitorDataService.GetQshMonitorDataInfoList(pageInfo); err != nil {
		global.GVA_LOG.Error("获取失败!", zap.Error(err))
		response.FailWithMessage("获取失败", c)
	} else {
		response.OkWithDetailed(response.PageResult{
			List:     list,
			Total:    total,
			Page:     pageInfo.Page,
			PageSize: pageInfo.PageSize,
		}, "获取成功", c)
	}
}
