package admin

import (
	"github.com/flipped-aurora/gin-vue-admin/server/global"
	"github.com/flipped-aurora/gin-vue-admin/server/model/admin"
	adminReq "github.com/flipped-aurora/gin-vue-admin/server/model/admin/request"
	"github.com/flipped-aurora/gin-vue-admin/server/model/common/request"
	"github.com/flipped-aurora/gin-vue-admin/server/model/common/response"
	"github.com/flipped-aurora/gin-vue-admin/server/service"
	"github.com/gin-gonic/gin"
	"go.uber.org/zap"
)

type QshPartolApi struct {
}

var qshPartolService = service.ServiceGroupApp.AdminServiceGroup.QshPartolService

// CreateQshPartol 创建QshPartol
// @Tags QshPartol
// @Summary 创建QshPartol
// @Security ApiKeyAuth
// @accept application/json
// @Produce application/json
// @Param data body admin.QshPartol true "创建QshPartol"
// @Success 200 {string} string "{"success":true,"data":{},"msg":"获取成功"}"
// @Router /qshPartol/createQshPartol [post]
func (qshPartolApi *QshPartolApi) CreateQshPartol(c *gin.Context) {
	var qshPartol admin.QshPatrol
	_ = c.ShouldBindJSON(&qshPartol)
	if err := qshPartolService.CreateQshPartol(qshPartol); err != nil {
		global.GVA_LOG.Error("创建失败!", zap.Error(err))
		response.FailWithMessage("创建失败", c)
	} else {
		response.OkWithMessage("创建成功", c)
	}
}

// DeleteQshPartol 删除QshPartol
// @Tags QshPartol
// @Summary 删除QshPartol
// @Security ApiKeyAuth
// @accept application/json
// @Produce application/json
// @Param data body admin.QshPartol true "删除QshPartol"
// @Success 200 {string} string "{"success":true,"data":{},"msg":"删除成功"}"
// @Router /qshPartol/deleteQshPartol [delete]
func (qshPartolApi *QshPartolApi) DeleteQshPartol(c *gin.Context) {
	var qshPartol admin.QshPatrol
	_ = c.ShouldBindJSON(&qshPartol)
	if err := qshPartolService.DeleteQshPartol(qshPartol); err != nil {
		global.GVA_LOG.Error("删除失败!", zap.Error(err))
		response.FailWithMessage("删除失败", c)
	} else {
		response.OkWithMessage("删除成功", c)
	}
}

// DeleteQshPartolByIds 批量删除QshPartol
// @Tags QshPartol
// @Summary 批量删除QshPartol
// @Security ApiKeyAuth
// @accept application/json
// @Produce application/json
// @Param data body request.IdsReq true "批量删除QshPartol"
// @Success 200 {string} string "{"success":true,"data":{},"msg":"批量删除成功"}"
// @Router /qshPartol/deleteQshPartolByIds [delete]
func (qshPartolApi *QshPartolApi) DeleteQshPartolByIds(c *gin.Context) {
	var IDS request.IdsReq
	_ = c.ShouldBindJSON(&IDS)
	if err := qshPartolService.DeleteQshPartolByIds(IDS); err != nil {
		global.GVA_LOG.Error("批量删除失败!", zap.Error(err))
		response.FailWithMessage("批量删除失败", c)
	} else {
		response.OkWithMessage("批量删除成功", c)
	}
}

// UpdateQshPartol 更新QshPartol
// @Tags QshPartol
// @Summary 更新QshPartol
// @Security ApiKeyAuth
// @accept application/json
// @Produce application/json
// @Param data body admin.QshPartol true "更新QshPartol"
// @Success 200 {string} string "{"success":true,"data":{},"msg":"更新成功"}"
// @Router /qshPartol/updateQshPartol [put]
func (qshPartolApi *QshPartolApi) UpdateQshPartol(c *gin.Context) {
	var qshPartol admin.QshPatrol
	_ = c.ShouldBindJSON(&qshPartol)
	if err := qshPartolService.UpdateQshPartol(qshPartol); err != nil {
		global.GVA_LOG.Error("更新失败!", zap.Error(err))
		response.FailWithMessage("更新失败", c)
	} else {
		response.OkWithMessage("更新成功", c)
	}
}

// FindQshPartol 用id查询QshPartol
// @Tags QshPartol
// @Summary 用id查询QshPartol
// @Security ApiKeyAuth
// @accept application/json
// @Produce application/json
// @Param data query admin.QshPartol true "用id查询QshPartol"
// @Success 200 {string} string "{"success":true,"data":{},"msg":"查询成功"}"
// @Router /qshPartol/findQshPartol [get]
func (qshPartolApi *QshPartolApi) FindQshPartol(c *gin.Context) {
	var qshPartol admin.QshPatrol
	_ = c.ShouldBindQuery(&qshPartol)
	if reqshPartol, err := qshPartolService.GetQshPartol(qshPartol.ID); err != nil {
		global.GVA_LOG.Error("查询失败!", zap.Error(err))
		response.FailWithMessage("查询失败", c)
	} else {
		response.OkWithData(gin.H{"reqshPartol": reqshPartol}, c)
	}
}

// GetQshPartolList 分页获取QshPartol列表
// @Tags QshPartol
// @Summary 分页获取QshPartol列表
// @Security ApiKeyAuth
// @accept application/json
// @Produce application/json
// @Param data query adminReq.QshPartolSearch true "分页获取QshPartol列表"
// @Success 200 {string} string "{"success":true,"data":{},"msg":"获取成功"}"
// @Router /qshPartol/getQshPartolList [get]
func (qshPartolApi *QshPartolApi) GetQshPartolList(c *gin.Context) {
	var pageInfo adminReq.QshPartolSearch
	_ = c.ShouldBindQuery(&pageInfo)
	if list, total, err := qshPartolService.GetQshPartolInfoList(pageInfo); err != nil {
		global.GVA_LOG.Error("获取失败!", zap.Error(err))
		response.FailWithMessage("获取失败", c)
	} else {
		response.OkWithDetailed(response.PageResult{
			List:     list,
			Total:    total,
			Page:     pageInfo.Page,
			PageSize: pageInfo.PageSize,
		}, "获取成功", c)
	}
}
