package admin

import (
	"github.com/flipped-aurora/gin-vue-admin/server/global"
    "github.com/flipped-aurora/gin-vue-admin/server/model/admin"
    "github.com/flipped-aurora/gin-vue-admin/server/model/common/request"
    adminReq "github.com/flipped-aurora/gin-vue-admin/server/model/admin/request"
    "github.com/flipped-aurora/gin-vue-admin/server/model/common/response"
    "github.com/flipped-aurora/gin-vue-admin/server/service"
    "github.com/gin-gonic/gin"
    "go.uber.org/zap"
)

type QshToiletApi struct {
}

var qshToiletService = service.ServiceGroupApp.AdminServiceGroup.QshToiletService


// CreateQshToilet 创建QshToilet
// @Tags QshToilet
// @Summary 创建QshToilet
// @Security ApiKeyAuth
// @accept application/json
// @Produce application/json
// @Param data body admin.QshToilet true "创建QshToilet"
// @Success 200 {string} string "{"success":true,"data":{},"msg":"获取成功"}"
// @Router /qshToilet/createQshToilet [post]
func (qshToiletApi *QshToiletApi) CreateQshToilet(c *gin.Context) {
	var qshToilet admin.QshToilet
	_ = c.ShouldBindJSON(&qshToilet)
	if err := qshToiletService.CreateQshToilet(qshToilet); err != nil {
        global.GVA_LOG.Error("创建失败!", zap.Error(err))
		response.FailWithMessage("创建失败", c)
	} else {
		response.OkWithMessage("创建成功", c)
	}
}

// DeleteQshToilet 删除QshToilet
// @Tags QshToilet
// @Summary 删除QshToilet
// @Security ApiKeyAuth
// @accept application/json
// @Produce application/json
// @Param data body admin.QshToilet true "删除QshToilet"
// @Success 200 {string} string "{"success":true,"data":{},"msg":"删除成功"}"
// @Router /qshToilet/deleteQshToilet [delete]
func (qshToiletApi *QshToiletApi) DeleteQshToilet(c *gin.Context) {
	var qshToilet admin.QshToilet
	_ = c.ShouldBindJSON(&qshToilet)
	if err := qshToiletService.DeleteQshToilet(qshToilet); err != nil {
        global.GVA_LOG.Error("删除失败!", zap.Error(err))
		response.FailWithMessage("删除失败", c)
	} else {
		response.OkWithMessage("删除成功", c)
	}
}

// DeleteQshToiletByIds 批量删除QshToilet
// @Tags QshToilet
// @Summary 批量删除QshToilet
// @Security ApiKeyAuth
// @accept application/json
// @Produce application/json
// @Param data body request.IdsReq true "批量删除QshToilet"
// @Success 200 {string} string "{"success":true,"data":{},"msg":"批量删除成功"}"
// @Router /qshToilet/deleteQshToiletByIds [delete]
func (qshToiletApi *QshToiletApi) DeleteQshToiletByIds(c *gin.Context) {
	var IDS request.IdsReq
    _ = c.ShouldBindJSON(&IDS)
	if err := qshToiletService.DeleteQshToiletByIds(IDS); err != nil {
        global.GVA_LOG.Error("批量删除失败!", zap.Error(err))
		response.FailWithMessage("批量删除失败", c)
	} else {
		response.OkWithMessage("批量删除成功", c)
	}
}

// UpdateQshToilet 更新QshToilet
// @Tags QshToilet
// @Summary 更新QshToilet
// @Security ApiKeyAuth
// @accept application/json
// @Produce application/json
// @Param data body admin.QshToilet true "更新QshToilet"
// @Success 200 {string} string "{"success":true,"data":{},"msg":"更新成功"}"
// @Router /qshToilet/updateQshToilet [put]
func (qshToiletApi *QshToiletApi) UpdateQshToilet(c *gin.Context) {
	var qshToilet admin.QshToilet
	_ = c.ShouldBindJSON(&qshToilet)
	if err := qshToiletService.UpdateQshToilet(qshToilet); err != nil {
        global.GVA_LOG.Error("更新失败!", zap.Error(err))
		response.FailWithMessage("更新失败", c)
	} else {
		response.OkWithMessage("更新成功", c)
	}
}

// FindQshToilet 用id查询QshToilet
// @Tags QshToilet
// @Summary 用id查询QshToilet
// @Security ApiKeyAuth
// @accept application/json
// @Produce application/json
// @Param data query admin.QshToilet true "用id查询QshToilet"
// @Success 200 {string} string "{"success":true,"data":{},"msg":"查询成功"}"
// @Router /qshToilet/findQshToilet [get]
func (qshToiletApi *QshToiletApi) FindQshToilet(c *gin.Context) {
	var qshToilet admin.QshToilet
	_ = c.ShouldBindQuery(&qshToilet)
	if reqshToilet, err := qshToiletService.GetQshToilet(qshToilet.ID); err != nil {
        global.GVA_LOG.Error("查询失败!", zap.Error(err))
		response.FailWithMessage("查询失败", c)
	} else {
		response.OkWithData(gin.H{"reqshToilet": reqshToilet}, c)
	}
}

// GetQshToiletList 分页获取QshToilet列表
// @Tags QshToilet
// @Summary 分页获取QshToilet列表
// @Security ApiKeyAuth
// @accept application/json
// @Produce application/json
// @Param data query adminReq.QshToiletSearch true "分页获取QshToilet列表"
// @Success 200 {string} string "{"success":true,"data":{},"msg":"获取成功"}"
// @Router /qshToilet/getQshToiletList [get]
func (qshToiletApi *QshToiletApi) GetQshToiletList(c *gin.Context) {
	var pageInfo adminReq.QshToiletSearch
	_ = c.ShouldBindQuery(&pageInfo)
	if list, total, err := qshToiletService.GetQshToiletInfoList(pageInfo); err != nil {
	    global.GVA_LOG.Error("获取失败!", zap.Error(err))
        response.FailWithMessage("获取失败", c)
    } else {
        response.OkWithDetailed(response.PageResult{
            List:     list,
            Total:    total,
            Page:     pageInfo.Page,
            PageSize: pageInfo.PageSize,
        }, "获取成功", c)
    }
}
