package admin

import (
	"github.com/flipped-aurora/gin-vue-admin/server/global"
	"github.com/flipped-aurora/gin-vue-admin/server/model/admin"
	adminReq "github.com/flipped-aurora/gin-vue-admin/server/model/admin/request"
	"github.com/flipped-aurora/gin-vue-admin/server/model/common/request"
	"github.com/flipped-aurora/gin-vue-admin/server/model/common/response"
	"github.com/flipped-aurora/gin-vue-admin/server/service"
	"github.com/gin-gonic/gin"
	"go.uber.org/zap"
)

type QshTypeApi struct {
}

var qshTypeService = service.ServiceGroupApp.AdminServiceGroup.QshTypeService

// CreateQshType 创建QshType
// @Tags QshType
// @Summary 创建QshType
// @Security ApiKeyAuth
// @accept application/json
// @Produce application/json
// @Param data body admin.QshType true "创建QshType"
// @Success 200 {string} string "{"success":true,"data":{},"msg":"获取成功"}"
// @Router /qshType/createQshType [post]
func (qshTypeApi *QshTypeApi) CreateQshType(c *gin.Context) {
	var qshType admin.QshType
	_ = c.ShouldBindJSON(&qshType)
	if err := qshTypeService.CreateQshType(qshType); err != nil {
		global.GVA_LOG.Error("创建失败!", zap.Error(err))
		response.FailWithMessage("创建失败", c)
	} else {
		response.OkWithMessage("创建成功", c)
	}
}

// DeleteQshType 删除QshType
// @Tags QshType
// @Summary 删除QshType
// @Security ApiKeyAuth
// @accept application/json
// @Produce application/json
// @Param data body admin.QshType true "删除QshType"
// @Success 200 {string} string "{"success":true,"data":{},"msg":"删除成功"}"
// @Router /qshType/deleteQshType [delete]
func (qshTypeApi *QshTypeApi) DeleteQshType(c *gin.Context) {
	var qshType admin.QshType
	_ = c.ShouldBindJSON(&qshType)
	if err := qshTypeService.DeleteQshType(qshType); err != nil {
		global.GVA_LOG.Error("删除失败!", zap.Error(err))
		response.FailWithMessage("删除失败", c)
	} else {
		response.OkWithMessage("删除成功", c)
	}
}

// DeleteQshTypeByIds 批量删除QshType
// @Tags QshType
// @Summary 批量删除QshType
// @Security ApiKeyAuth
// @accept application/json
// @Produce application/json
// @Param data body request.IdsReq true "批量删除QshType"
// @Success 200 {string} string "{"success":true,"data":{},"msg":"批量删除成功"}"
// @Router /qshType/deleteQshTypeByIds [delete]
func (qshTypeApi *QshTypeApi) DeleteQshTypeByIds(c *gin.Context) {
	var IDS request.IdsReq
	_ = c.ShouldBindJSON(&IDS)
	if err := qshTypeService.DeleteQshTypeByIds(IDS); err != nil {
		global.GVA_LOG.Error("批量删除失败!", zap.Error(err))
		response.FailWithMessage("批量删除失败", c)
	} else {
		response.OkWithMessage("批量删除成功", c)
	}
}

// UpdateQshType 更新QshType
// @Tags QshType
// @Summary 更新QshType
// @Security ApiKeyAuth
// @accept application/json
// @Produce application/json
// @Param data body admin.QshType true "更新QshType"
// @Success 200 {string} string "{"success":true,"data":{},"msg":"更新成功"}"
// @Router /qshType/updateQshType [put]
func (qshTypeApi *QshTypeApi) UpdateQshType(c *gin.Context) {
	var qshType admin.QshType
	_ = c.ShouldBindJSON(&qshType)
	if err := qshTypeService.UpdateQshType(qshType); err != nil {
		global.GVA_LOG.Error("更新失败!", zap.Error(err))
		response.FailWithMessage("更新失败", c)
	} else {
		response.OkWithMessage("更新成功", c)
	}
}

// FindQshType 用id查询QshType
// @Tags QshType
// @Summary 用id查询QshType
// @Security ApiKeyAuth
// @accept application/json
// @Produce application/json
// @Param data query admin.QshType true "用id查询QshType"
// @Success 200 {string} string "{"success":true,"data":{},"msg":"查询成功"}"
// @Router /qshType/findQshType [get]
func (qshTypeApi *QshTypeApi) FindQshType(c *gin.Context) {
	var qshType admin.QshType
	_ = c.ShouldBindQuery(&qshType)
	if reqshType, err := qshTypeService.GetQshType(qshType.ID); err != nil {
		global.GVA_LOG.Error("查询失败!", zap.Error(err))
		response.FailWithMessage("查询失败", c)
	} else {
		response.OkWithData(gin.H{"reqshType": reqshType}, c)
	}
}

// GetQshTypeList 分页获取QshType列表
// @Tags QshType
// @Summary 分页获取QshType列表
// @Security ApiKeyAuth
// @accept application/json
// @Produce application/json
// @Param data query adminReq.QshTypeSearch true "分页获取QshType列表"
// @Success 200 {string} string "{"success":true,"data":{},"msg":"获取成功"}"
// @Router /qshType/getQshTypeList [get]
func (qshTypeApi *QshTypeApi) GetQshTypeList(c *gin.Context) {
	var pageInfo adminReq.QshTypeSearch
	_ = c.ShouldBindQuery(&pageInfo)
	if list, total, err := qshTypeService.GetQshTypeInfoList(pageInfo); err != nil {
		global.GVA_LOG.Error("获取失败!", zap.Error(err))
		response.FailWithMessage("获取失败", c)
	} else {
		response.OkWithDetailed(response.PageResult{
			List:     list,
			Total:    total,
			Page:     pageInfo.Page,
			PageSize: pageInfo.PageSize,
		}, "获取成功", c)
	}
}
