package web

import (
	"gitee.com/zjlsliupei/ghelp"
	"github.com/flipped-aurora/gin-vue-admin/server/global"
	"github.com/flipped-aurora/gin-vue-admin/server/model/common/response"
	"github.com/flipped-aurora/gin-vue-admin/server/model/system"
	"github.com/flipped-aurora/gin-vue-admin/server/request"
	"github.com/flipped-aurora/gin-vue-admin/server/service"
	"github.com/flipped-aurora/gin-vue-admin/server/utils"
	"github.com/gin-gonic/gin"
	"go.uber.org/zap"
	"time"
)

var (
	userService  = service.ServiceGroupApp.SystemServiceGroup.UserService
	loginService = service.ServiceGroupApp.WebServiceGroup.LoginService
)

func Login(c *gin.Context) {

	var l request.Login
	_ = c.ShouldBindJSON(&l)
	if err := utils.Verify(l, utils.LoginVerify); err != nil {
		response.FailWithMessage(err.Error(), c)
		return
	}
	u := &system.SysUser{Username: l.Username, Password: l.Password}

	key := ghelp.Md5(ghelp.CreateUnique())
	prefix := global.GVA_VP.GetString("redis.prefix")
	prefixKey := prefix + key
	if user, err := userService.Login(u); err != nil {
		global.GVA_LOG.Error("登陆失败! 用户名不存在或者密码错误!", zap.Error(err))
		response.FailWithMessage("用户名不存在或者密码错误", c)
	} else {
		if user.Enable != 1 {
			global.GVA_LOG.Error("登陆失败! 用户被禁止登录!")
			response.FailWithMessage("用户被禁止登录", c)
			return
		}
		value := ghelp.MAP{
			"user_id": user.ID,
		}
		if err = global.GVA_REDIS.Set(c, prefixKey, ghelp.JsonEncode(value), 86400*time.Second).Err(); err != nil {
			response.FailWithMessage("登录失败，请联系管理人员！", c)
			return
		}
		response.OkWithData(key, c)
	}
}
