package admin

import (
	"github.com/flipped-aurora/gin-vue-admin/server/global"
	"github.com/flipped-aurora/gin-vue-admin/server/model/admin"
	adminReq "github.com/flipped-aurora/gin-vue-admin/server/model/admin/request"
	"github.com/flipped-aurora/gin-vue-admin/server/model/common/request"
)

type QshMonitorDataService struct {
}

// CreateQshMonitorData 创建QshMonitorData记录
// Author [piexlmax](https://github.com/piexlmax)
func (qshMonitorDataService *QshMonitorDataService) CreateQshMonitorData(qshMonitorData admin.QshMonitorData) (err error) {
	err = global.GVA_DB.Create(&qshMonitorData).Error
	return err
}

// DeleteQshMonitorData 删除QshMonitorData记录
// Author [piexlmax](https://github.com/piexlmax)
func (qshMonitorDataService *QshMonitorDataService) DeleteQshMonitorData(qshMonitorData admin.QshMonitorData) (err error) {
	err = global.GVA_DB.Delete(&qshMonitorData).Error
	return err
}

// DeleteQshMonitorDataByIds 批量删除QshMonitorData记录
// Author [piexlmax](https://github.com/piexlmax)
func (qshMonitorDataService *QshMonitorDataService) DeleteQshMonitorDataByIds(ids request.IdsReq) (err error) {
	err = global.GVA_DB.Delete(&[]admin.QshMonitorData{}, "id in ?", ids.Ids).Error
	return err
}

// UpdateQshMonitorData 更新QshMonitorData记录
// Author [piexlmax](https://github.com/piexlmax)
func (qshMonitorDataService *QshMonitorDataService) UpdateQshMonitorData(qshMonitorData admin.QshMonitorData) (err error) {
	err = global.GVA_DB.Save(&qshMonitorData).Error
	return err
}

// GetQshMonitorData 根据id获取QshMonitorData记录
// Author [piexlmax](https://github.com/piexlmax)
func (qshMonitorDataService *QshMonitorDataService) GetQshMonitorData(id uint) (qshMonitorData admin.QshMonitorData, err error) {
	err = global.GVA_DB.Where("id = ?", id).First(&qshMonitorData).Error
	return
}

// GetQshMonitorDataInfoList 分页获取QshMonitorData记录
// Author [piexlmax](https://github.com/piexlmax)
func (qshMonitorDataService *QshMonitorDataService) GetQshMonitorDataInfoList(info adminReq.QshMonitorDataSearch) (list interface{}, total int64, err error) {
	limit := info.PageSize
	offset := info.PageSize * (info.Page - 1)
	// 创建db
	db := global.GVA_DB.Model(&admin.QshMonitorData{})
	var qshMonitorDatas []admin.QshMonitorData
	// 如果有条件搜索 下方会自动创建搜索语句
	if info.RawDeviceId != "" {
		db = db.Where("raw_device_id = ?", info.RawDeviceId)
	}
	if info.TypeName != "" {
		db = db.Where("type_name LIKE ?", "%"+info.TypeName+"%")
	}
	err = db.Count(&total).Error
	if err != nil {
		return
	}
	err = db.Limit(limit).Offset(offset).Order("created_at desc").Find(&qshMonitorDatas).Error
	return qshMonitorDatas, total, err
}
