package web

import (
	"errors"
	"github.com/flipped-aurora/gin-vue-admin/server/global"
	"github.com/flipped-aurora/gin-vue-admin/server/model/admin"
	"github.com/flipped-aurora/gin-vue-admin/server/request"
	"github.com/flipped-aurora/gin-vue-admin/server/server"
)

type DataService struct {
}

//DataInYeWei 接受液位数据
func (s *DataService) DataInYeWei(arg server.YeWeiData) error {
	//先查询设备绑定厕所
	var toiletInfo admin.QshToilet
	err := global.GVA_DB.Model(admin.QshToilet{}).Where("yewei_device = ?", arg.DeviceId).First(&toiletInfo).Error
	if err != nil {
		return errors.New("设备ID未绑定公厕信息！")
	}
	return global.GVA_DB.Create(&admin.QshMonitorData{
		ToiletId:    int(toiletInfo.ID),
		RawDeviceId: arg.DeviceId,
		TypeName:    "液位",
		Value:       arg.YeWei,
		Unit:        "m",
	}).Error
}

//GetYewei 获取液位
func (s *DataService) GetYewei(arg request.GetYewei) (admin.QshMonitorData, error) {
	var data admin.QshMonitorData
	err := global.GVA_DB.Model(admin.QshMonitorData{}).Where("toilet_id = ?", arg.ToiletID).Where("type_name = ?", "液位").Last(&data).Error
	if err != nil {
		return data, err
	}
	return data, nil
}

//GetHistoryDataList 获取历史数据
func (s *DataService) GetHistoryDataList(arg request.GetHistoryDataList) ([]admin.QshMonitorData, int64, error) {
	var count int64
	var data []admin.QshMonitorData
	limit := arg.PageSize
	offset := (arg.Page - 1) * arg.PageSize
	db := global.GVA_DB.Model(admin.QshMonitorData{})
	if arg.ToiletID != 0 {
		db.Where("toilet_id = ?", arg.ToiletID)
	}
	if arg.TypeName != "" {
		db.Where("type_name = ?", arg.TypeName)
	}
	if arg.StartTime != "" {
		db.Where("created_at >= ?", arg.StartTime)
	}
	if arg.EndTime != "" {
		db.Where("created_at <= ?", arg.EndTime)
	}
	db.Count(&count)
	err := db.Limit(limit).Offset(offset).Order("created_at desc").Find(&data).Error
	if err != nil {
		return data, count, err
	}
	return data, count, nil
}
