package web

import (
	"crypto/hmac"
	"crypto/sha1"
	"encoding/base64"
	"encoding/json"
	"github.com/flipped-aurora/gin-vue-admin/server/global"
	"hash"
	"io"
	"time"
)

type OssService struct {
}

type CallbackParam struct {
	CallbackUrl      string `json:"callbackUrl"`
	CallbackBody     string `json:"callbackBody"`
	CallbackBodyType string `json:"callbackBodyType"`
}
type ConfigStruct struct {
	Expiration string     `json:"expiration"`
	Conditions [][]string `json:"conditions"`
}

const (
	base64Table = "123QRSTUabcdVWXYZHijKLAWDCABDstEFGuvwxyzGHIJklmnopqr234560178912"
)

var coder = base64.NewEncoding(base64Table)

func base64Encode(src []byte) []byte {
	return []byte(coder.EncodeToString(src))
}
func get_gmt_iso8601(expire_end int64) string {
	var tokenExpire = time.Unix(expire_end, 0).UTC().Format("2006-01-02T15:04:05Z")
	return tokenExpire
}

type PolicyToken struct {
	AccessKeyId string `json:"accessid"`  //keyId
	Host        string `json:"host"`      //地址
	Expire      int64  `json:"expire"`    //过期时间
	Signature   string `json:"signature"` //签名
	Policy      string `json:"policy"`    //
	Directory   string `json:"dir"`       //目录
	Callback    string `json:"callback"`  //回调
}

func (s *OssService) GetPolicyToken() PolicyToken {
	// AccessKeyId。
	accessKeyId := global.GVA_VP.GetString("oss.AccessId")
	// AccessKeySecret。
	accessKeySecret := global.GVA_VP.GetString("oss.AccessKey")
	// host的格式为 bucketname.endpoint
	ossHost := global.GVA_VP.GetString("oss.OssHost")
	prefix := global.GVA_VP.GetString("oss.prefix")
	host := "//" + ossHost

	// callbackUrl为 上传回调服务器的URL，请将下面的IP和Port配置为您自己的真实信息。
	var callbackUrl = "http://88.88.88.88:8888"
	// 用户上传文件时指定的前缀。
	var uploadDir = prefix + time.Now().Format("2006-01-02")
	var expireTime = time.Now().Unix() + 7200
	now := time.Now().Unix()
	expireEnd := now + expireTime
	var tokenExpire = get_gmt_iso8601(expireEnd)

	//create post policy json
	var config ConfigStruct
	config.Expiration = tokenExpire
	var condition []string
	condition = append(condition, "starts-with")
	condition = append(condition, "$key")
	condition = append(condition, uploadDir)
	config.Conditions = append(config.Conditions, condition)

	//calucate signature
	result, err := json.Marshal(config)
	debyte := base64.StdEncoding.EncodeToString(result)
	h := hmac.New(func() hash.Hash { return sha1.New() }, []byte(accessKeySecret))
	io.WriteString(h, debyte)
	signedStr := base64.StdEncoding.EncodeToString(h.Sum(nil))

	var callbackParam CallbackParam
	callbackParam.CallbackUrl = callbackUrl
	callbackParam.CallbackBody = "filename=${object}&size=${size}&mimeType=${mimeType}&height=${imageInfo.height}&width=${imageInfo.width}"
	callbackParam.CallbackBodyType = "application/x-www-form-urlencoded"
	callbackStr, err := json.Marshal(callbackParam)
	if err != nil {

	}
	callbackBase64 := base64.StdEncoding.EncodeToString(callbackStr)

	var policyToken PolicyToken
	policyToken.AccessKeyId = accessKeyId
	policyToken.Host = host
	policyToken.Expire = expireEnd
	policyToken.Signature = string(signedStr)
	policyToken.Directory = uploadDir
	policyToken.Policy = string(debyte)
	policyToken.Callback = string(callbackBase64)
	return policyToken
}
