package utils

import (
	"context"
	"errors"
	"fmt"
	"github.com/beego/beego/v2/client/httplib"
	"github.com/flipped-aurora/gin-vue-admin/server/global"
	"github.com/songzhibin97/gkit/tools/gjson"
	"time"
)

type PageInfo struct {
	Page     int `json:"page" form:"page"`           // 页码
	PageSize int `json:"page_size" form:"page_size"` // 每页大小
}

// GetYinShiAccessToken 获取指定帐号下accessToken
// example: utils.GetYinShiAccessToken("13625717783")
func GetYinShiAccessToken(userName string) (string, error) {
	key := fmt.Sprintf("%syinshui_accesstoken_%s", global.GVA_VP.GetString("redis.prefix"), userName)
	if accessToken := global.GVA_REDIS.Get(context.Background(), key).Val(); accessToken != "" {
		return accessToken, nil
	}
	req := httplib.Post("https://open.ys7.com/api/lapp/token/get")
	req.Param("appKey", global.GVA_VP.GetString(fmt.Sprintf("yinShiYun.%s.appKey", userName)))
	req.Param("appSecret", global.GVA_VP.GetString(fmt.Sprintf("yinShiYun.%s.secret", userName)))
	res, err := req.String()
	if err != nil {
		return "", err
	}
	resJson := gjson.Parse(res)
	if resJson.Get("code").Exists() && resJson.Get("code").Int() == 200 {
		_accessToken := resJson.Get("data.accessToken").String()
		global.GVA_REDIS.Set(context.Background(), key, _accessToken, 6*24*time.Hour)
		return _accessToken, nil
	} else {
		return "", errors.New("获取accessToken失败")
	}
}

// GetCameraUrl 获取监控播放地址
func GetCameraUrl(deviceId string) string {
	return fmt.Sprintf("ezopen://open.ys7.com/%s/1.hd.live", deviceId)
}
